@@ -64,6 +64,8 @@ class Patchbay(QMainWindow):
 
     def closeEvent(self, event):
         """Override parent closeEvent to save settings first."""
+        if self.patch:
+            close_patch(self.patch)
         self.save_settings()
         QMainWindow.closeEvent(self, event)
 
@@ -71,7 +73,8 @@ class Patchbay(QMainWindow):
         """Select and open a new patch to use."""
         f_name, _ = QFileDialog.getOpenFileName(self, caption='Select a patch to load',
                                                 filter='Patches (*.pbp, *.py)')
-        self.set_patch(f_name)
+        if f_name:
+            self.set_patch(f_name)
 
     def set_patch(self, filename):
         if filename is None:
@@ -82,6 +85,7 @@ class Patchbay(QMainWindow):
             self.patch = patch_module.Patch(self)
 
             self.setCentralWidget(self.patch.ui)
+            self.setWindowTitle(self.patch.title)
             self.actions['close'].setDisabled(False)
 
     def close_patch(self):
@@ -91,4 +95,5 @@ class Patchbay(QMainWindow):
         self.patch = None
 
         self.setCentralWidget(QFrame())
+        self.setWindowTitle('patchbay')
         self.actions['close'].setDisabled(True)
